[Lldb-commits] [lldb] e9264b7 - [lldb] NFC: Fix trivial typo in comments, documents, and messages

Kazuaki Ishizaki via lldb-commits lldb-commits at lists.llvm.org
Mon Apr 6 09:06:37 PDT 2020


Author: Kazuaki Ishizaki
Date: 2020-04-07T01:06:16+09:00
New Revision: e9264b746b81a63323d884ea07b2ebfbb660d004

URL: https://github.com/llvm/llvm-project/commit/e9264b746b81a63323d884ea07b2ebfbb660d004
DIFF: https://github.com/llvm/llvm-project/commit/e9264b746b81a63323d884ea07b2ebfbb660d004.diff

LOG: [lldb] NFC: Fix trivial typo in comments, documents, and messages

Differential Revision: https://reviews.llvm.org/D77460

Added: 
    

Modified: 
    lldb/bindings/interface/SBBlock.i
    lldb/bindings/interface/SBExpressionOptions.i
    lldb/bindings/interface/SBFile.i
    lldb/docs/lldb-platform-packets.txt
    lldb/examples/interposing/darwin/fd_interposing/FDInterposing.cpp
    lldb/examples/python/mach_o.py
    lldb/include/lldb/Symbol/LineEntry.h
    lldb/include/lldb/Symbol/SymbolFile.h
    lldb/include/lldb/Target/Platform.h
    lldb/include/lldb/Target/Process.h
    lldb/include/lldb/Target/Target.h
    lldb/include/lldb/Target/ThreadPlan.h
    lldb/include/lldb/Utility/Connection.h
    lldb/include/lldb/Utility/Reproducer.h
    lldb/include/lldb/Utility/Status.h
    lldb/packages/Python/lldbsuite/test/lldbtest.py
    lldb/packages/Python/lldbsuite/test/test_runner/README.txt
    lldb/packages/Python/lldbsuite/test/tools/lldb-vscode/vscode.py
    lldb/scripts/verify_api.py
    lldb/source/Commands/CommandObjectWatchpoint.cpp
    lldb/source/Core/FormatEntity.cpp
    lldb/source/Host/common/Editline.cpp
    lldb/source/Host/common/NativeProcessProtocol.cpp
    lldb/source/Plugins/ABI/ARC/ABISysV_arc.cpp
    lldb/source/Plugins/DynamicLoader/MacOSX-DYLD/DynamicLoaderDarwin.cpp
    lldb/source/Plugins/DynamicLoader/POSIX-DYLD/DynamicLoaderPOSIXDYLD.h
    lldb/source/Plugins/ExpressionParser/Clang/ClangExpressionParser.cpp
    lldb/source/Plugins/ExpressionParser/Clang/CppModuleConfiguration.h
    lldb/source/Plugins/Instruction/ARM/EmulateInstructionARM.cpp
    lldb/source/Plugins/Instruction/MIPS/EmulateInstructionMIPS.h
    lldb/source/Plugins/Instruction/MIPS64/EmulateInstructionMIPS64.h
    lldb/source/Plugins/Language/CPlusPlus/CPlusPlusLanguage.cpp
    lldb/source/Plugins/LanguageRuntime/CPlusPlus/CPPLanguageRuntime.h
    lldb/source/Plugins/ObjectFile/ELF/ObjectFileELF.cpp
    lldb/source/Plugins/Platform/MacOSX/PlatformDarwin.h
    lldb/source/Plugins/Process/Darwin/CFUtils.h
    lldb/source/Plugins/Process/Linux/NativeRegisterContextLinux_arm.cpp
    lldb/source/Plugins/Process/Linux/NativeRegisterContextLinux_arm64.cpp
    lldb/source/Plugins/Process/Linux/NativeRegisterContextLinux_mips64.cpp
    lldb/source/Plugins/Process/Linux/NativeRegisterContextLinux_ppc64le.cpp
    lldb/source/Plugins/Process/MacOSX-Kernel/CommunicationKDP.cpp
    lldb/source/Plugins/Process/Utility/RegisterInfos_arm64.h
    lldb/source/Plugins/Process/Windows/Common/NativeProcessWindows.cpp
    lldb/source/Plugins/Process/gdb-remote/GDBRemoteCommunicationServerLLGS.cpp
    lldb/source/Plugins/Process/gdb-remote/ProcessGDBRemote.cpp
    lldb/source/Plugins/Process/mach-core/ProcessMachCore.cpp
    lldb/source/Plugins/Process/minidump/ProcessMinidump.cpp
    lldb/source/Plugins/ScriptInterpreter/Python/PythonDataObjects.cpp
    lldb/source/Plugins/ScriptInterpreter/Python/PythonDataObjects.h
    lldb/source/Plugins/StructuredData/DarwinLog/StructuredDataDarwinLog.h
    lldb/source/Plugins/SymbolFile/PDB/SymbolFilePDB.cpp
    lldb/source/Plugins/TypeSystem/Clang/TypeSystemClang.cpp
    lldb/source/Symbol/ArmUnwindInfo.cpp
    lldb/source/Target/RegisterContextUnwind.cpp
    lldb/source/Target/StackFrame.cpp
    lldb/source/Target/StopInfo.cpp
    lldb/test/API/benchmarks/turnaround/TestCompileRunToBreakpointTurnaround.py
    lldb/test/API/functionalities/breakpoint/breakpoint_names/TestBreakpointNames.py
    lldb/test/API/functionalities/breakpoint/step_over_breakpoint/TestStepOverBreakpoint.py
    lldb/test/API/functionalities/load_unload/TestLoadUnload.py
    lldb/test/API/functionalities/plugins/python_os_plugin/TestPythonOSPlugin.py
    lldb/test/API/functionalities/process_crash_info/TestProcessCrashInfo.py
    lldb/test/API/functionalities/target-new-solib-notifications/TestModuleLoadedNotifys.py
    lldb/test/API/lang/cpp/namespace/ns3.cpp
    lldb/test/API/macosx/lc-note/kern-ver-str/TestKernVerStrLCNOTE.py
    lldb/test/API/macosx/lc-note/kern-ver-str/create-empty-corefile.cpp
    lldb/test/API/python_api/default-constructor/TestDefaultConstructorForAPIObjects.py
    lldb/test/API/python_api/frame/TestFrames.py
    lldb/test/API/python_api/function_symbol/main.c
    lldb/test/API/python_api/target/main.c
    lldb/test/API/python_api/thread/TestThreadAPI.py
    lldb/test/API/tools/lldb-server/main.cpp
    lldb/test/API/tools/lldb-vscode/attach/TestVSCode_attach.py
    lldb/test/API/tools/lldb-vscode/breakpoint-events/TestVSCode_breakpointEvents.py
    lldb/test/API/tools/lldb-vscode/breakpoint/TestVSCode_setBreakpoints.py
    lldb/test/API/tools/lldb-vscode/breakpoint/TestVSCode_setExceptionBreakpoints.py
    lldb/test/API/tools/lldb-vscode/breakpoint/TestVSCode_setFunctionBreakpoints.py
    lldb/test/API/tools/lldb-vscode/launch/TestVSCode_launch.py
    lldb/test/API/tools/lldb-vscode/stackTrace/TestVSCode_stackTrace.py
    lldb/test/API/tools/lldb-vscode/step/TestVSCode_step.py
    lldb/test/Shell/SymbolFile/DWARF/anon_class_w_and_wo_export_symbols.ll
    lldb/third_party/Python/module/pexpect-4.6/pexpect/spawnbase.py
    lldb/tools/debugserver/source/ChangeLog
    lldb/tools/debugserver/source/MacOSX/CFUtils.h
    lldb/tools/debugserver/source/MacOSX/MachProcess.h
    lldb/tools/lldb-test/lldb-test.cpp
    lldb/tools/lldb-vscode/JSONUtils.h
    lldb/tools/lldb-vscode/package.json
    lldb/unittests/Process/Linux/ProcessorTraceTest.cpp
    lldb/unittests/Utility/ArchSpecTest.cpp
    lldb/unittests/debugserver/CMakeLists.txt

Removed: 
    


################################################################################
diff  --git a/lldb/bindings/interface/SBBlock.i b/lldb/bindings/interface/SBBlock.i
index 8bd8e37953cf..812b41fe5c3e 100644
--- a/lldb/bindings/interface/SBBlock.i
+++ b/lldb/bindings/interface/SBBlock.i
@@ -152,7 +152,7 @@ public:
         sibling = property(GetSibling, None, doc='''A read only property that returns the same result as GetSibling().''')
         name = property(GetInlinedName, None, doc='''A read only property that returns the same result as GetInlinedName().''')
         inlined_block = property(GetContainingInlinedBlock, None, doc='''A read only property that returns the same result as GetContainingInlinedBlock().''')
-        range = property(get_ranges_access_object, None, doc='''A read only property that allows item access to the address ranges for a block by integer (range = block.range[0]) and by lldb.SBAdddress (find the range that contains the specified lldb.SBAddress like "pc_range = lldb.frame.block.range[frame.addr]").''')
+        range = property(get_ranges_access_object, None, doc='''A read only property that allows item access to the address ranges for a block by integer (range = block.range[0]) and by lldb.SBAddress (find the range that contains the specified lldb.SBAddress like "pc_range = lldb.frame.block.range[frame.addr]").''')
         ranges = property(get_ranges_array, None, doc='''A read only property that returns a list() object that contains all of the address ranges for the block.''')
         num_ranges = property(GetNumRanges, None, doc='''A read only property that returns the same result as GetNumRanges().''')
     %}

diff  --git a/lldb/bindings/interface/SBExpressionOptions.i b/lldb/bindings/interface/SBExpressionOptions.i
index 33a6ed745a8d..950641c320de 100644
--- a/lldb/bindings/interface/SBExpressionOptions.i
+++ b/lldb/bindings/interface/SBExpressionOptions.i
@@ -59,7 +59,7 @@ public:
     uint32_t
     GetTimeoutInMicroSeconds () const;
 
-    %feature("docstring", "Sets the timeout in microseconds to run the expression for. If try all threads is set to true and the expression doesn't complete within the specified timeout, all threads will be resumed for the same timeout to see if the expresson will finish.") SetTimeoutInMicroSeconds;
+    %feature("docstring", "Sets the timeout in microseconds to run the expression for. If try all threads is set to true and the expression doesn't complete within the specified timeout, all threads will be resumed for the same timeout to see if the expression will finish.") SetTimeoutInMicroSeconds;
     void
     SetTimeoutInMicroSeconds (uint32_t timeout = 0);
 
@@ -80,7 +80,7 @@ public:
     bool
     GetStopOthers () const;
 
-    %feature("docstring", "Sets whether to stop other threads at all while running expressins.  If false, TryAllThreads does nothing.") SetTryAllThreads;
+    %feature("docstring", "Sets whether to stop other threads at all while running expressions.  If false, TryAllThreads does nothing.") SetTryAllThreads;
     void
     SetStopOthers (bool stop_others = true);
 

diff  --git a/lldb/bindings/interface/SBFile.i b/lldb/bindings/interface/SBFile.i
index a19666995cd3..c86c5f26f147 100644
--- a/lldb/bindings/interface/SBFile.i
+++ b/lldb/bindings/interface/SBFile.i
@@ -92,7 +92,7 @@ public:
     SBFile, call SBFile.Close().
 
     If there is no underlying python file to unwrap, GetFile will
-    use the file descriptor, if availble to create a new python
+    use the file descriptor, if available to create a new python
     file object using `open(fd, mode=..., closefd=False)`
     ");
     FileSP GetFile();

diff  --git a/lldb/docs/lldb-platform-packets.txt b/lldb/docs/lldb-platform-packets.txt
index ed5d71701715..23d1cacc5f7e 100644
--- a/lldb/docs/lldb-platform-packets.txt
+++ b/lldb/docs/lldb-platform-packets.txt
@@ -351,7 +351,7 @@ incompatible with the flags that gdb specifies.
 //  response is F followed by the opened file descriptor in base 10.
 //  "F-1,errno" with the errno if an error occurs.
 //
-//  COMPATABILITY
+//  COMPATIBILITY
 //    The gdb-remote serial protocol documentatio defines a vFile:open:
 //    packet which uses incompatible flag values, e.g. 1 means O_WRONLY
 //    in gdb's vFile:open:, but it means eOpenOptionRead to lldb's

diff  --git a/lldb/examples/interposing/darwin/fd_interposing/FDInterposing.cpp b/lldb/examples/interposing/darwin/fd_interposing/FDInterposing.cpp
index e3f429cdf30e..a39370cc29ed 100644
--- a/lldb/examples/interposing/darwin/fd_interposing/FDInterposing.cpp
+++ b/lldb/examples/interposing/darwin/fd_interposing/FDInterposing.cpp
@@ -147,7 +147,7 @@ typedef std::tr1::shared_ptr<String> StringSP;
 
 // FDEvent
 //
-// A class that describes a file desciptor event.
+// A class that describes a file descriptor event.
 //
 // File descriptor events fall into one of two categories: create events
 // and delete events.
@@ -185,7 +185,7 @@ class FDEvent {
   // The frames for the stack backtrace for this event
   Frames m_frames;
   // If this is a file descriptor delete event, this might contain
-  // the correspoding file descriptor create event
+  // the corresponding file descriptor create event
   FDEventSP m_create_event_sp;
   // The file descriptor for this event
   int m_fd;
@@ -232,18 +232,18 @@ typedef std::map<int, FDEventArray> FDEventMap;
 // event is detected, the open event will be removed and placed into
 // the close event so if something tries to double close a file
 // descriptor we can show the previous close event and the file
-// desctiptor event that created it. When a new file descriptor create
+// descriptor event that created it. When a new file descriptor create
 // event comes in, we will remove the previous one for that file
-// desctiptor unless the environment variable
+// descriptor unless the environment variable
 // "FileDescriptorStackLoggingNoCompact"
-// is set. The file desctiptor history can be accessed using the
+// is set. The file descriptor history can be accessed using the
 // get_fd_history() function.
 static FDEventMap g_fd_event_map;
 // A mutex to protect access to our data structures in g_fd_event_map
 // and also our logging messages
 static pthread_mutex_t g_mutex = PTHREAD_MUTEX_INITIALIZER;
 // Log all file descriptor create and close events by default. Only log
-// warnings and erros if the "FileDescriptorMinimalLogging" environment
+// warnings and errors if the "FileDescriptorMinimalLogging" environment
 // variable is set.
 static int g_log_all_calls = 1;
 // We compact the file descriptor events by default. Set the environment
@@ -498,7 +498,7 @@ void save_backtrace(int fd, int err, const StringSP &string_sp,
             fd);
       } else if (g_compact) {
         // We are compacting so we remove previous create event
-        // when we get the correspinding delete event
+        // when we get the corresponding delete event
         event_array.pop_back();
       }
     } else {
@@ -518,7 +518,7 @@ void save_backtrace(int fd, int err, const StringSP &string_sp,
         // that this close if for...
         fd_event_sp->SetCreateEvent(event_array.back());
         // We are compacting so we remove previous create event
-        // when we get the correspinding delete event
+        // when we get the corresponding delete event
         event_array.pop_back();
       }
     }

diff  --git a/lldb/examples/python/mach_o.py b/lldb/examples/python/mach_o.py
index eb97fe57cfc1..1780bc3e3209 100755
--- a/lldb/examples/python/mach_o.py
+++ b/lldb/examples/python/mach_o.py
@@ -965,7 +965,7 @@ def compare(self, rhs):
                         result = False
                         print('error: section %s is missing in %s' % (lhs_section.sectname, rhs.path))
             else:
-                print('error: comaparing a %s mach-o file with a %s mach-o file is not supported' % (self.type, rhs.type))
+                print('error: comparing a %s mach-o file with a %s mach-o file is not supported' % (self.type, rhs.type))
                 result = False
             if not result:
                 print('error: mach files 
diff er')

diff  --git a/lldb/include/lldb/Symbol/LineEntry.h b/lldb/include/lldb/Symbol/LineEntry.h
index 5623439bc64b..7e56ef814765 100644
--- a/lldb/include/lldb/Symbol/LineEntry.h
+++ b/lldb/include/lldb/Symbol/LineEntry.h
@@ -118,7 +118,7 @@ struct LineEntry {
   /// range.
   ///
   /// If the initial LineEntry this method is called on is a line #0, only the
-  /// range of contiuous LineEntries with line #0 will be included in the
+  /// range of continuous LineEntries with line #0 will be included in the
   /// complete range.
   ///
   /// @param[in] include_inlined_functions

diff  --git a/lldb/include/lldb/Symbol/SymbolFile.h b/lldb/include/lldb/Symbol/SymbolFile.h
index 4dc49cdd0391..bc2b6b8f212e 100644
--- a/lldb/include/lldb/Symbol/SymbolFile.h
+++ b/lldb/include/lldb/Symbol/SymbolFile.h
@@ -182,7 +182,7 @@ class SymbolFile : public PluginInterface {
   };
   /// If \c type_uid points to an array type, return its characteristics.
   /// To support variable-length array types, this function takes an
-  /// optional \p ExtecutionContext. If \c exe_ctx is non-null, the
+  /// optional \p ExecutionContext. If \c exe_ctx is non-null, the
   /// dynamic characteristics for that context are returned.
   virtual llvm::Optional<ArrayInfo>
   GetDynamicArrayInfoForUID(lldb::user_id_t type_uid,

diff  --git a/lldb/include/lldb/Target/Platform.h b/lldb/include/lldb/Target/Platform.h
index 06290b34ac0e..190ad0653073 100644
--- a/lldb/include/lldb/Target/Platform.h
+++ b/lldb/include/lldb/Target/Platform.h
@@ -827,18 +827,18 @@ class Platform : public PluginInterface {
   virtual size_t ConnectToWaitingProcesses(lldb_private::Debugger &debugger,
                                            lldb_private::Status &error);
 
-  /// Gather all of crash informations into a structured data dictionnary.
+  /// Gather all of crash informations into a structured data dictionary.
   ///
   /// If the platform have a crashed process with crash information entries,
-  /// gather all the entries into an structured data dictionnary or return a
-  /// nullptr. This dictionnary is generic and extensible, as it contains an
+  /// gather all the entries into an structured data dictionary or return a
+  /// nullptr. This dictionary is generic and extensible, as it contains an
   /// array for each 
diff erent type of crash information.
   ///
   /// \param[in] process
   ///     The crashed process.
   ///
   /// \return
-  ///     A structured data dictionnary containing at each entry, the crash
+  ///     A structured data dictionary containing at each entry, the crash
   ///     information type as the entry key and the matching  an array as the
   ///     entry value. \b nullptr if not implemented or  if the process has no
   ///     crash information entry. \b error if an error occured.

diff  --git a/lldb/include/lldb/Target/Process.h b/lldb/include/lldb/Target/Process.h
index 82c302c08e11..c5a1544a87a5 100644
--- a/lldb/include/lldb/Target/Process.h
+++ b/lldb/include/lldb/Target/Process.h
@@ -2922,7 +2922,7 @@ void PruneThreadPlans();
   DISALLOW_COPY_AND_ASSIGN(Process);
 };
 
-/// RAII guard that should be aquired when an utility function is called within
+/// RAII guard that should be acquired when an utility function is called within
 /// a given process.
 class UtilityFunctionScope {
   Process *m_process;

diff  --git a/lldb/include/lldb/Target/Target.h b/lldb/include/lldb/Target/Target.h
index 27997e5ea76d..b2cdea5c5d7a 100644
--- a/lldb/include/lldb/Target/Target.h
+++ b/lldb/include/lldb/Target/Target.h
@@ -963,7 +963,7 @@ class Target : public std::enable_shared_from_this<Target>,
   ///
   /// \param[in] set_platform
   ///     If \b true, then the platform will be adjusted if the currently
-  ///     selected platform is not compatible with the archicture being set.
+  ///     selected platform is not compatible with the architecture being set.
   ///     If \b false, then just the architecture will be set even if the
   ///     currently selected platform isn't compatible (in case it might be
   ///     manually set following this function call).

diff  --git a/lldb/include/lldb/Target/ThreadPlan.h b/lldb/include/lldb/Target/ThreadPlan.h
index 5b7bea21f30b..65bb7a2d11a4 100644
--- a/lldb/include/lldb/Target/ThreadPlan.h
+++ b/lldb/include/lldb/Target/ThreadPlan.h
@@ -251,7 +251,7 @@ namespace lldb_private {
 //  However, if the plan doesn't want to be
 //  the stop reason, then it can call SetPlanComplete and pass in "false" for
 //  the "success" parameter.  In that case,
-//  the real stop reason will be used instead.  One exapmle of this is the
+//  the real stop reason will be used instead.  One example of this is the
 //  "StepRangeStepIn" thread plan.  If it stops
 //  because of a crash or breakpoint hit, it wants to unship itself, because it
 //  isn't so useful to have step in keep going

diff  --git a/lldb/include/lldb/Utility/Connection.h b/lldb/include/lldb/Utility/Connection.h
index 6ca493c36615..1c3221df4ce4 100644
--- a/lldb/include/lldb/Utility/Connection.h
+++ b/lldb/include/lldb/Utility/Connection.h
@@ -125,7 +125,7 @@ class Connection {
   /// Subclasses must override this function.
   ///
   /// \param[in] dst
-  ///     A desination buffer that must be at least \a dst_len bytes
+  ///     A destination buffer that must be at least \a dst_len bytes
   ///     long.
   ///
   /// \param[in] dst_len

diff  --git a/lldb/include/lldb/Utility/Reproducer.h b/lldb/include/lldb/Utility/Reproducer.h
index b8b897d02ea2..10d2c801bc95 100644
--- a/lldb/include/lldb/Utility/Reproducer.h
+++ b/lldb/include/lldb/Utility/Reproducer.h
@@ -134,7 +134,7 @@ class VersionProvider : public Provider<VersionProvider> {
   static char ID;
 };
 
-/// Provider for the LLDB current working directroy.
+/// Provider for the LLDB current working directory.
 ///
 /// When the reproducer is kept, it writes lldb's current working directory to
 /// a file named cwd.txt in the reproducer root.

diff  --git a/lldb/include/lldb/Utility/Status.h b/lldb/include/lldb/Utility/Status.h
index 1d9816613358..9babad18edc0 100644
--- a/lldb/include/lldb/Utility/Status.h
+++ b/lldb/include/lldb/Utility/Status.h
@@ -111,7 +111,7 @@ class Status {
 
   /// Set accessor from a kern_return_t.
   ///
-  /// Set accesssor for the error value to \a err and the error type to \c
+  /// Set accessor for the error value to \a err and the error type to \c
   /// MachKernel.
   ///
   /// \param[in] err
@@ -123,9 +123,9 @@ class Status {
   int SetExpressionErrorWithFormat(lldb::ExpressionResults, const char *format,
                                    ...) __attribute__((format(printf, 3, 4)));
 
-  /// Set accesssor with an error value and type.
+  /// Set accessor with an error value and type.
   ///
-  /// Set accesssor for the error value to \a err and the error type to \a
+  /// Set accessor for the error value to \a err and the error type to \a
   /// type.
   ///
   /// \param[in] err

diff  --git a/lldb/packages/Python/lldbsuite/test/lldbtest.py b/lldb/packages/Python/lldbsuite/test/lldbtest.py
index 5058594505f5..3cea39ddcd57 100644
--- a/lldb/packages/Python/lldbsuite/test/lldbtest.py
+++ b/lldb/packages/Python/lldbsuite/test/lldbtest.py
@@ -642,7 +642,7 @@ def setPlatformWorkingDir(self):
         lldb.remote_platform.SetWorkingDirectory(remote_test_dir)
 
         # This function removes all files from the current working directory while leaving
-        # the directories in place. The cleaup is required to reduce the disk space required
+        # the directories in place. The cleanup is required to reduce the disk space required
         # by the test suite while leaving the directories untouched is neccessary because
         # sub-directories might belong to an other test
         def clean_working_directory():
@@ -942,12 +942,12 @@ def restore_stdout():
     # =======================================================================
 
     def setTearDownCleanup(self, dictionary=None):
-        """Register a cleanup action at tearDown() time with a dictinary"""
+        """Register a cleanup action at tearDown() time with a dictionary"""
         self.dict = dictionary
         self.doTearDownCleanup = True
 
     def addTearDownCleanup(self, dictionary):
-        """Add a cleanup action at tearDown() time with a dictinary"""
+        """Add a cleanup action at tearDown() time with a dictionary"""
         self.dicts.append(dictionary)
         self.doTearDownCleanups = True
 
@@ -1152,7 +1152,7 @@ def dumpSessionInfo(self):
 
         # We are here because self.tearDown() detected that this test instance
         # either errored or failed.  The lldb.test_result singleton contains
-        # two lists (erros and failures) which get populated by the unittest
+        # two lists (errors and failures) which get populated by the unittest
         # framework.  Look over there for stack trace information.
         #
         # The lists contain 2-tuples of TestCase instances and strings holding

diff  --git a/lldb/packages/Python/lldbsuite/test/test_runner/README.txt b/lldb/packages/Python/lldbsuite/test/test_runner/README.txt
index bb40870e7965..b90bf4c73417 100644
--- a/lldb/packages/Python/lldbsuite/test/test_runner/README.txt
+++ b/lldb/packages/Python/lldbsuite/test/test_runner/README.txt
@@ -1,5 +1,5 @@
 This directory contains source and tests for the lldb test runner
 architecture.  This directory is not for lldb python tests.  It
-is the test runner.  The tests under this diretory are test-runner
+is the test runner.  The tests under this directory are test-runner
 tests (i.e. tests that verify the test runner itself runs properly).
 

diff  --git a/lldb/packages/Python/lldbsuite/test/tools/lldb-vscode/vscode.py b/lldb/packages/Python/lldbsuite/test/tools/lldb-vscode/vscode.py
index 3cdf1ee90ccb..7c966bcc04ee 100644
--- a/lldb/packages/Python/lldbsuite/test/tools/lldb-vscode/vscode.py
+++ b/lldb/packages/Python/lldbsuite/test/tools/lldb-vscode/vscode.py
@@ -161,7 +161,7 @@ def handle_recv_packet(self, packet):
            indicate a new packet is available. Returns True if the caller
            should keep calling this function for more packets.
         '''
-        # If EOF, notify the read thread by enqueing a None.
+        # If EOF, notify the read thread by enqueuing a None.
         if not packet:
             self.enqueue_recv_packet(None)
             return False
@@ -788,7 +788,7 @@ def request_threads(self):
             self.threads = body['threads']
             for thread in self.threads:
                 # Copy the thread dictionary so we can add key/value pairs to
-                # it without affecfting the original info from the "threads"
+                # it without affecting the original info from the "threads"
                 # command.
                 tid = thread['id']
                 if tid in self.thread_stop_reasons:
@@ -1018,7 +1018,7 @@ def main():
         dest='attach',
         default=False,
         help=('Specify this option to attach to a process by name. The '
-              'process name is the basanme of the executable specified with '
+              'process name is the basename of the executable specified with '
               'the --program option.'))
 
     parser.add_option(

diff  --git a/lldb/scripts/verify_api.py b/lldb/scripts/verify_api.py
index d422cded8c29..f3f0748023bc 100755
--- a/lldb/scripts/verify_api.py
+++ b/lldb/scripts/verify_api.py
@@ -48,7 +48,7 @@ def verify_api(all_args):
         type='string',
         action='append',
         dest='archs',
-        help='architecure to use when checking the api')
+        help='architecture to use when checking the api')
     parser.add_option(
         '-r',
         '--api-regex',

diff  --git a/lldb/source/Commands/CommandObjectWatchpoint.cpp b/lldb/source/Commands/CommandObjectWatchpoint.cpp
index e0dfbd40b8fb..63baae8e4760 100644
--- a/lldb/source/Commands/CommandObjectWatchpoint.cpp
+++ b/lldb/source/Commands/CommandObjectWatchpoint.cpp
@@ -1038,7 +1038,7 @@ class CommandObjectWatchpointSetExpression : public CommandObjectRaw {
     // set a watchpoint.
     if (raw_command.trim().empty()) {
       result.GetErrorStream().Printf("error: required argument missing; "
-                                     "specify an expression to evaulate into "
+                                     "specify an expression to evaluate into "
                                      "the address to watch for\n");
       result.SetStatus(eReturnStatusFailed);
       return false;

diff  --git a/lldb/source/Core/FormatEntity.cpp b/lldb/source/Core/FormatEntity.cpp
index b258b6f5413b..d491ac14bec8 100644
--- a/lldb/source/Core/FormatEntity.cpp
+++ b/lldb/source/Core/FormatEntity.cpp
@@ -2409,7 +2409,7 @@ void FormatEntity::AutoComplete(CompletionRequest &request) {
 
   llvm::StringRef partial_variable(str.substr(dollar_pos + 2));
   if (partial_variable.empty()) {
-    // Suggest all top level entites as we are just past "${"
+    // Suggest all top level entities as we are just past "${"
     StringList new_matches;
     AddMatches(&g_root, str, llvm::StringRef(), new_matches);
     request.AddCompletions(new_matches);

diff  --git a/lldb/source/Host/common/Editline.cpp b/lldb/source/Host/common/Editline.cpp
index 60dc9ab0cabc..b72e951a2e28 100644
--- a/lldb/source/Host/common/Editline.cpp
+++ b/lldb/source/Host/common/Editline.cpp
@@ -35,7 +35,7 @@ using namespace lldb_private::line_editor;
 // with until TERM is set to VT100 where it stumbles over an implementation
 // assumption that may not exist on other platforms.  The setupterm() function
 // would normally require headers that don't work gracefully in this context,
-// so the function declaraction has been hoisted here.
+// so the function declaration has been hoisted here.
 #if defined(__APPLE__)
 extern "C" {
 int setupterm(char *term, int fildes, int *errret);

diff  --git a/lldb/source/Host/common/NativeProcessProtocol.cpp b/lldb/source/Host/common/NativeProcessProtocol.cpp
index 1bea50a5ad27..a4d0b4181d58 100644
--- a/lldb/source/Host/common/NativeProcessProtocol.cpp
+++ b/lldb/source/Host/common/NativeProcessProtocol.cpp
@@ -650,7 +650,7 @@ Status NativeProcessProtocol::ReadMemoryWithoutTrap(lldb::addr_t addr,
     auto saved_opcodes = makeArrayRef(pair.second.saved_opcodes);
 
     if (bp_addr + saved_opcodes.size() < addr || addr + bytes_read <= bp_addr)
-      continue; // Breapoint not in range, ignore
+      continue; // Breakpoint not in range, ignore
 
     if (bp_addr < addr) {
       saved_opcodes = saved_opcodes.drop_front(addr - bp_addr);

diff  --git a/lldb/source/Plugins/ABI/ARC/ABISysV_arc.cpp b/lldb/source/Plugins/ABI/ARC/ABISysV_arc.cpp
index 10e3b0ff2f7d..a212eef2ab8a 100644
--- a/lldb/source/Plugins/ABI/ARC/ABISysV_arc.cpp
+++ b/lldb/source/Plugins/ABI/ARC/ABISysV_arc.cpp
@@ -522,7 +522,7 @@ ValueObjectSP ABISysV_arc::GetReturnValueObjectImpl(Thread &thread,
   // Integer return type.
   else if (retType.isIntegerTy()) {
     size_t byte_size = retType.getPrimitiveSizeInBits();
-    if (1 != byte_size) // For boolian type.
+    if (1 != byte_size) // For boolean type.
       byte_size /= CHAR_BIT;
 
     auto raw_value = ReadRawValue(reg_ctx, byte_size);

diff  --git a/lldb/source/Plugins/DynamicLoader/MacOSX-DYLD/DynamicLoaderDarwin.cpp b/lldb/source/Plugins/DynamicLoader/MacOSX-DYLD/DynamicLoaderDarwin.cpp
index 0c471007a305..f2735212dff9 100644
--- a/lldb/source/Plugins/DynamicLoader/MacOSX-DYLD/DynamicLoaderDarwin.cpp
+++ b/lldb/source/Plugins/DynamicLoader/MacOSX-DYLD/DynamicLoaderDarwin.cpp
@@ -681,7 +681,7 @@ bool DynamicLoaderDarwin::AddModulesUsingImageInfos(
         loaded_module_list.AppendIfNeeded(image_module_sp);
       }
 
-      // macCataylst support:
+      // macCatalyst support:
       // Update the module's platform with the DYLD info.
       ArchSpec dyld_spec = image_infos[idx].GetArchitecture();
       if (dyld_spec.GetTriple().getOS() == llvm::Triple::IOS &&

diff  --git a/lldb/source/Plugins/DynamicLoader/POSIX-DYLD/DynamicLoaderPOSIXDYLD.h b/lldb/source/Plugins/DynamicLoader/POSIX-DYLD/DynamicLoaderPOSIXDYLD.h
index 3befb9005e50..3ea6c5a7919a 100644
--- a/lldb/source/Plugins/DynamicLoader/POSIX-DYLD/DynamicLoaderPOSIXDYLD.h
+++ b/lldb/source/Plugins/DynamicLoader/POSIX-DYLD/DynamicLoaderPOSIXDYLD.h
@@ -136,7 +136,7 @@ class DynamicLoaderPOSIXDYLD : public lldb_private::DynamicLoader {
 
   void LoadVDSO();
 
-  // Loading an interpreter module (if present) assumming m_interpreter_base
+  // Loading an interpreter module (if present) assuming m_interpreter_base
   // already points to its base address.
   lldb::ModuleSP LoadInterpreterModule();
 

diff  --git a/lldb/source/Plugins/ExpressionParser/Clang/ClangExpressionParser.cpp b/lldb/source/Plugins/ExpressionParser/Clang/ClangExpressionParser.cpp
index 9996f2608e31..e7afbe5c3031 100644
--- a/lldb/source/Plugins/ExpressionParser/Clang/ClangExpressionParser.cpp
+++ b/lldb/source/Plugins/ExpressionParser/Clang/ClangExpressionParser.cpp
@@ -716,7 +716,7 @@ class CodeComplete : public CodeCompleteConsumer {
     return cmd;
   }
 
-  /// Attemps to merge the given completion from the given position into the
+  /// Attempts to merge the given completion from the given position into the
   /// existing command. Returns the completion string that can be returned to
   /// the lldb completion API.
   std::string mergeCompletion(StringRef existing, unsigned pos,

diff  --git a/lldb/source/Plugins/ExpressionParser/Clang/CppModuleConfiguration.h b/lldb/source/Plugins/ExpressionParser/Clang/CppModuleConfiguration.h
index 7fc27375b82d..235ac2bd090c 100644
--- a/lldb/source/Plugins/ExpressionParser/Clang/CppModuleConfiguration.h
+++ b/lldb/source/Plugins/ExpressionParser/Clang/CppModuleConfiguration.h
@@ -56,7 +56,7 @@ class CppModuleConfiguration {
   bool analyzeFile(const FileSpec &f);
 
 public:
-  /// Creates a configuraiton by analyzing the given list of used source files.
+  /// Creates a configuration by analyzing the given list of used source files.
   ///
   /// Currently only looks at the used paths and doesn't actually access the
   /// files on the disk.

diff  --git a/lldb/source/Plugins/Instruction/ARM/EmulateInstructionARM.cpp b/lldb/source/Plugins/Instruction/ARM/EmulateInstructionARM.cpp
index 34f88d2b4443..9837e33773d9 100644
--- a/lldb/source/Plugins/Instruction/ARM/EmulateInstructionARM.cpp
+++ b/lldb/source/Plugins/Instruction/ARM/EmulateInstructionARM.cpp
@@ -7223,7 +7223,7 @@ bool EmulateInstructionARM::EmulateLDRHImmediate(const uint32_t opcode,
   return true;
 }
 
-// LDRH (literal) caculates an address from the PC value and an immediate
+// LDRH (literal) calculates an address from the PC value and an immediate
 // offset, loads a halfword from memory,
 // zero-extends it to form a 32-bit word, and writes it to a register.
 bool EmulateInstructionARM::EmulateLDRHLiteral(const uint32_t opcode,
@@ -8509,7 +8509,7 @@ bool EmulateInstructionARM::EmulateSXTH(const uint32_t opcode,
   return true;
 }
 
-// UXTB extracts an 8-bit value from a register, zero-extneds it to 32 bits, and
+// UXTB extracts an 8-bit value from a register, zero-extends it to 32 bits, and
 // writes the result to the destination
 // register.  You can specify a rotation by 0, 8, 16, or 24 bits before
 // extracting the 8-bit value.

diff  --git a/lldb/source/Plugins/Instruction/MIPS/EmulateInstructionMIPS.h b/lldb/source/Plugins/Instruction/MIPS/EmulateInstructionMIPS.h
index c72501d16e13..61291c729879 100644
--- a/lldb/source/Plugins/Instruction/MIPS/EmulateInstructionMIPS.h
+++ b/lldb/source/Plugins/Instruction/MIPS/EmulateInstructionMIPS.h
@@ -203,7 +203,7 @@ class EmulateInstructionMIPS : public lldb_private::EmulateInstruction {
 
   bool nonvolatile_reg_p(uint32_t regnum);
 
-  const char *GetRegisterName(unsigned reg_num, bool altnernate_name);
+  const char *GetRegisterName(unsigned reg_num, bool alternate_name);
 
 private:
   std::unique_ptr<llvm::MCDisassembler> m_disasm;

diff  --git a/lldb/source/Plugins/Instruction/MIPS64/EmulateInstructionMIPS64.h b/lldb/source/Plugins/Instruction/MIPS64/EmulateInstructionMIPS64.h
index 35a0959b1704..c4ae2296c5dd 100644
--- a/lldb/source/Plugins/Instruction/MIPS64/EmulateInstructionMIPS64.h
+++ b/lldb/source/Plugins/Instruction/MIPS64/EmulateInstructionMIPS64.h
@@ -168,7 +168,7 @@ class EmulateInstructionMIPS64 : public lldb_private::EmulateInstruction {
 
   bool nonvolatile_reg_p(uint64_t regnum);
 
-  const char *GetRegisterName(unsigned reg_num, bool altnernate_name);
+  const char *GetRegisterName(unsigned reg_num, bool alternate_name);
 
 private:
   std::unique_ptr<llvm::MCDisassembler> m_disasm;

diff  --git a/lldb/source/Plugins/Language/CPlusPlus/CPlusPlusLanguage.cpp b/lldb/source/Plugins/Language/CPlusPlus/CPlusPlusLanguage.cpp
index ecb577e0c531..9d7d4902e0a6 100644
--- a/lldb/source/Plugins/Language/CPlusPlus/CPlusPlusLanguage.cpp
+++ b/lldb/source/Plugins/Language/CPlusPlus/CPlusPlusLanguage.cpp
@@ -127,7 +127,7 @@ static bool IsTrivialBasename(const llvm::StringRef &basename) {
     return false; // Empty string or "~"
 
   if (!std::isalpha(basename[idx]) && basename[idx] != '_')
-    return false; // First charater (after removing the possible '~'') isn't in
+    return false; // First character (after removing the possible '~'') isn't in
                   // [A-Za-z_]
 
   // Read all characters matching [A-Za-z_0-9]

diff  --git a/lldb/source/Plugins/LanguageRuntime/CPlusPlus/CPPLanguageRuntime.h b/lldb/source/Plugins/LanguageRuntime/CPlusPlus/CPPLanguageRuntime.h
index e83d578986aa..71725361e6ae 100644
--- a/lldb/source/Plugins/LanguageRuntime/CPlusPlus/CPPLanguageRuntime.h
+++ b/lldb/source/Plugins/LanguageRuntime/CPlusPlus/CPPLanguageRuntime.h
@@ -69,7 +69,7 @@ class CPPLanguageRuntime : public LanguageRuntime {
   /// Obtain a ThreadPlan to get us into C++ constructs such as std::function.
   ///
   /// \param[in] thread
-  ///     Curent thrad of execution.
+  ///     Current thrad of execution.
   ///
   /// \param[in] stop_others
   ///     True if other threads should pause during execution.

diff  --git a/lldb/source/Plugins/ObjectFile/ELF/ObjectFileELF.cpp b/lldb/source/Plugins/ObjectFile/ELF/ObjectFileELF.cpp
index 2b3779ec7826..e7b6d56e885d 100644
--- a/lldb/source/Plugins/ObjectFile/ELF/ObjectFileELF.cpp
+++ b/lldb/source/Plugins/ObjectFile/ELF/ObjectFileELF.cpp
@@ -2781,7 +2781,7 @@ Symtab *ObjectFileELF::GetSymtab() {
       m_symtab_up.reset(new Symtab(this));
 
     // In the event that there's no symbol entry for the entry point we'll
-    // artifically create one. We delegate to the symtab object the figuring
+    // artificially create one. We delegate to the symtab object the figuring
     // out of the proper size, this will usually make it span til the next
     // symbol it finds in the section. This means that if there are missing
     // symbols the entry point might span beyond its function definition.
@@ -2878,7 +2878,7 @@ void ObjectFileELF::ParseUnwindSymbols(Symtab *symbol_table,
     return;
 
   // First we save the new symbols into a separate list and add them to the
-  // symbol table after we colleced all symbols we want to add. This is
+  // symbol table after we collected all symbols we want to add. This is
   // neccessary because adding a new symbol invalidates the internal index of
   // the symtab what causing the next lookup to be slow because it have to
   // recalculate the index first.

diff  --git a/lldb/source/Plugins/Platform/MacOSX/PlatformDarwin.h b/lldb/source/Plugins/Platform/MacOSX/PlatformDarwin.h
index 5bdc61c98ae5..619a8595fa21 100644
--- a/lldb/source/Plugins/Platform/MacOSX/PlatformDarwin.h
+++ b/lldb/source/Plugins/Platform/MacOSX/PlatformDarwin.h
@@ -106,7 +106,7 @@ class PlatformDarwin : public PlatformPOSIX {
   static lldb_private::FileSpec GetXcodeContentsDirectory();
   static lldb_private::FileSpec GetXcodeDeveloperDirectory();
 
-  /// Return the toolchain directroy the current LLDB instance is located in.
+  /// Return the toolchain directory the current LLDB instance is located in.
   static lldb_private::FileSpec GetCurrentToolchainDirectory();
 
   /// Return the command line tools directory the current LLDB instance is

diff  --git a/lldb/source/Plugins/Process/Darwin/CFUtils.h b/lldb/source/Plugins/Process/Darwin/CFUtils.h
index b567524ce63a..0ef7b18c55fe 100644
--- a/lldb/source/Plugins/Process/Darwin/CFUtils.h
+++ b/lldb/source/Plugins/Process/Darwin/CFUtils.h
@@ -22,7 +22,7 @@
 // explicitly released using the release() member function.
 template <class T> class CFReleaser {
 public:
-  // Type names for the avlue
+  // Type names for the value
   typedef T element_type;
 
   // Constructors and destructors

diff  --git a/lldb/source/Plugins/Process/Linux/NativeRegisterContextLinux_arm.cpp b/lldb/source/Plugins/Process/Linux/NativeRegisterContextLinux_arm.cpp
index 9328c8bd69df..a83491e6d898 100644
--- a/lldb/source/Plugins/Process/Linux/NativeRegisterContextLinux_arm.cpp
+++ b/lldb/source/Plugins/Process/Linux/NativeRegisterContextLinux_arm.cpp
@@ -566,7 +566,7 @@ uint32_t NativeRegisterContextLinux_arm::SetHardwareWatchpoint(
 
   // Check 4-byte alignment for hardware watchpoint target address. Below is a
   // hack to recalculate address and size in order to make sure we can watch
-  // non 4-byte alligned addresses as well.
+  // non 4-byte aligned addresses as well.
   if (addr & 0x03) {
     uint8_t watch_mask = (addr & 0x03) + size;
 
@@ -861,7 +861,7 @@ Status NativeRegisterContextLinux_arm::DoReadRegisterValue(
   // PTRACE_PEEKUSER don't work in the aarch64 linux kernel used on android
   // devices (always return "Bad address"). To avoid using PTRACE_PEEKUSER we
   // read out the full GPR register set instead. This approach is about 4 times
-  // slower but the performance overhead is negligible in comparision to
+  // slower but the performance overhead is negligible in comparison to
   // processing time in lldb-server.
   assert(offset % 4 == 0 && "Try to write a register with unaligned offset");
   if (offset + sizeof(uint32_t) > sizeof(m_gpr_arm))
@@ -881,7 +881,7 @@ Status NativeRegisterContextLinux_arm::DoWriteRegisterValue(
   // devices (always return "Bad address"). To avoid using PTRACE_POKEUSER we
   // read out the full GPR register set, modify the requested register and
   // write it back. This approach is about 4 times slower but the performance
-  // overhead is negligible in comparision to processing time in lldb-server.
+  // overhead is negligible in comparison to processing time in lldb-server.
   assert(offset % 4 == 0 && "Try to write a register with unaligned offset");
   if (offset + sizeof(uint32_t) > sizeof(m_gpr_arm))
     return Status("Register isn't fit into the size of the GPR area");

diff  --git a/lldb/source/Plugins/Process/Linux/NativeRegisterContextLinux_arm64.cpp b/lldb/source/Plugins/Process/Linux/NativeRegisterContextLinux_arm64.cpp
index 9ae3a27e6feb..d39044f6bdaf 100644
--- a/lldb/source/Plugins/Process/Linux/NativeRegisterContextLinux_arm64.cpp
+++ b/lldb/source/Plugins/Process/Linux/NativeRegisterContextLinux_arm64.cpp
@@ -571,7 +571,7 @@ uint32_t NativeRegisterContextLinux_arm64::SetHardwareWatchpoint(
 
   // Check 8-byte alignment for hardware watchpoint target address. Below is a
   // hack to recalculate address and size in order to make sure we can watch
-  // non 8-byte alligned addresses as well.
+  // non 8-byte aligned addresses as well.
   if (addr & 0x07) {
     uint8_t watch_mask = (addr & 0x07) + size;
 

diff  --git a/lldb/source/Plugins/Process/Linux/NativeRegisterContextLinux_mips64.cpp b/lldb/source/Plugins/Process/Linux/NativeRegisterContextLinux_mips64.cpp
index 1640c4672eaa..b0a4ad94ce0b 100644
--- a/lldb/source/Plugins/Process/Linux/NativeRegisterContextLinux_mips64.cpp
+++ b/lldb/source/Plugins/Process/Linux/NativeRegisterContextLinux_mips64.cpp
@@ -679,7 +679,7 @@ static int GetVacantWatchIndex(struct pt_watch_regs *regs, lldb::addr_t addr,
     }
 
     if (vacant_watches > 1) {
-      // Split this watchpoint accross several registers
+      // Split this watchpoint across several registers
       struct pt_watch_regs regs_copy;
       regs_copy = *regs;
       lldb::addr_t break_addr;

diff  --git a/lldb/source/Plugins/Process/Linux/NativeRegisterContextLinux_ppc64le.cpp b/lldb/source/Plugins/Process/Linux/NativeRegisterContextLinux_ppc64le.cpp
index 0120bc030283..6d1a15a0b70b 100644
--- a/lldb/source/Plugins/Process/Linux/NativeRegisterContextLinux_ppc64le.cpp
+++ b/lldb/source/Plugins/Process/Linux/NativeRegisterContextLinux_ppc64le.cpp
@@ -552,7 +552,7 @@ uint32_t NativeRegisterContextLinux_ppc64le::SetHardwareWatchpoint(
 
   // Check 8-byte alignment for hardware watchpoint target address. Below is a
   // hack to recalculate address and size in order to make sure we can watch
-  // non 8-byte alligned addresses as well.
+  // non 8-byte aligned addresses as well.
   if (addr & 0x07) {
 
     addr_t begin = llvm::alignDown(addr, 8);

diff  --git a/lldb/source/Plugins/Process/MacOSX-Kernel/CommunicationKDP.cpp b/lldb/source/Plugins/Process/MacOSX-Kernel/CommunicationKDP.cpp
index 5afd84aa65ee..ae2627488d6a 100644
--- a/lldb/source/Plugins/Process/MacOSX-Kernel/CommunicationKDP.cpp
+++ b/lldb/source/Plugins/Process/MacOSX-Kernel/CommunicationKDP.cpp
@@ -304,7 +304,7 @@ bool CommunicationKDP::CheckForPacket(const uint8_t *src, size_t src_len,
       if (length <= bytes_available) {
         // We have an entire packet ready, we need to copy the data bytes into
         // a buffer that will be owned by the packet and erase the bytes from
-        // our communcation buffer "m_bytes"
+        // our communication buffer "m_bytes"
         packet.SetData(DataBufferSP(new DataBufferHeap(&m_bytes[0], length)));
         m_bytes.erase(0, length);
 

diff  --git a/lldb/source/Plugins/Process/Utility/RegisterInfos_arm64.h b/lldb/source/Plugins/Process/Utility/RegisterInfos_arm64.h
index 68c12aa6e529..0a0979c92071 100644
--- a/lldb/source/Plugins/Process/Utility/RegisterInfos_arm64.h
+++ b/lldb/source/Plugins/Process/Utility/RegisterInfos_arm64.h
@@ -521,7 +521,7 @@ static uint32_t g_d31_invalidates[] = {fpu_v31, fpu_s31, LLDB_INVALID_REGNUM};
         0                                                                      \
   }
 
-// Defines S and D pseudo registers mapping over correspondig vector register
+// Defines S and D pseudo registers mapping over corresponding vector register
 #define DEFINE_FPU_PSEUDO(reg, size, offset, vreg)                             \
   {                                                                            \
     #reg, nullptr, size, FPU_OFFSET(fpu_##vreg - fpu_v0) + offset,             \

diff  --git a/lldb/source/Plugins/Process/Windows/Common/NativeProcessWindows.cpp b/lldb/source/Plugins/Process/Windows/Common/NativeProcessWindows.cpp
index ecb747123980..5a6153cf72ab 100644
--- a/lldb/source/Plugins/Process/Windows/Common/NativeProcessWindows.cpp
+++ b/lldb/source/Plugins/Process/Windows/Common/NativeProcessWindows.cpp
@@ -394,7 +394,7 @@ void NativeProcessWindows::OnDebuggerConnected(lldb::addr_t image_base) {
            GetDebuggedProcessId(), image_base);
 
   // This is the earliest chance we can resolve the process ID and
-  // architecutre if we don't know them yet.
+  // architecture if we don't know them yet.
   if (GetID() == LLDB_INVALID_PROCESS_ID)
     SetID(GetDebuggedProcessId());
 

diff  --git a/lldb/source/Plugins/Process/gdb-remote/GDBRemoteCommunicationServerLLGS.cpp b/lldb/source/Plugins/Process/gdb-remote/GDBRemoteCommunicationServerLLGS.cpp
index ce889c94d512..3e7ab27802a8 100644
--- a/lldb/source/Plugins/Process/gdb-remote/GDBRemoteCommunicationServerLLGS.cpp
+++ b/lldb/source/Plugins/Process/gdb-remote/GDBRemoteCommunicationServerLLGS.cpp
@@ -947,7 +947,7 @@ GDBRemoteCommunicationServerLLGS::SendStopReplyPacketForThread(
                   reg_set_p->name ? reg_set_p->name : "<unnamed-set>",
                   *reg_num_p);
       } else if (reg_info_p->value_regs == nullptr) {
-        // Only expediate registers that are not contained in other registers.
+        // Only expedite registers that are not contained in other registers.
         RegisterValue reg_value;
         Status error = reg_ctx.ReadRegister(reg_info_p, reg_value);
         if (error.Success()) {

diff  --git a/lldb/source/Plugins/Process/gdb-remote/ProcessGDBRemote.cpp b/lldb/source/Plugins/Process/gdb-remote/ProcessGDBRemote.cpp
index 618ed7ccc040..d2e7f4d479cb 100644
--- a/lldb/source/Plugins/Process/gdb-remote/ProcessGDBRemote.cpp
+++ b/lldb/source/Plugins/Process/gdb-remote/ProcessGDBRemote.cpp
@@ -3791,7 +3791,7 @@ thread_result_t ProcessGDBRemote::AsyncThread(void *arg) {
               } // switch(stop_state)
             }   // else // if in All-stop-mode
           }     // if (continue_packet)
-        }       // case eBroadcastBitAysncContinue
+        }       // case eBroadcastBitAsyncContinue
         break;
 
         case eBroadcastBitAsyncThreadShouldExit:
@@ -4682,7 +4682,7 @@ llvm::Expected<LoadedModuleInfoList> ProcessGDBRemote::GetLoadedModuleList() {
                   // value.
                   module.set_base_is_offset(true);
                 } else if (name == "l_ld") {
-                  // the memory address of the libraries PT_DYAMIC section.
+                  // the memory address of the libraries PT_DYNAMIC section.
                   module.set_dynamic(StringConvert::ToUInt64(
                       value.data(), LLDB_INVALID_ADDRESS, 0));
                 }

diff  --git a/lldb/source/Plugins/Process/mach-core/ProcessMachCore.cpp b/lldb/source/Plugins/Process/mach-core/ProcessMachCore.cpp
index 1628dc545c9b..b78276d345e1 100644
--- a/lldb/source/Plugins/Process/mach-core/ProcessMachCore.cpp
+++ b/lldb/source/Plugins/Process/mach-core/ProcessMachCore.cpp
@@ -477,7 +477,7 @@ Status ProcessMachCore::DoLoadCore() {
     // segments are usually meaningless, they may be just "read", because we're
     // dealing with kernel coredumps or early startup coredumps and the dumper
     // is grabbing pages of memory without knowing what they are.  If they
-    // aren't marked as "exeuctable", that can break the unwinder which will
+    // aren't marked as "executable", that can break the unwinder which will
     // check a pc value to see if it is in an executable segment and stop the
     // backtrace early if it is not ("executable" and "unknown" would both be
     // fine, but "not executable" will break the unwinder).

diff  --git a/lldb/source/Plugins/Process/minidump/ProcessMinidump.cpp b/lldb/source/Plugins/Process/minidump/ProcessMinidump.cpp
index 0ce3b580c1f5..fc8ee346f449 100644
--- a/lldb/source/Plugins/Process/minidump/ProcessMinidump.cpp
+++ b/lldb/source/Plugins/Process/minidump/ProcessMinidump.cpp
@@ -257,7 +257,7 @@ void ProcessMinidump::RefreshStateAfterStop() {
 
     // TODO: The definition and use of this "dump requested" constant
     // in Breakpad are actually Linux-specific, and for similar use
-    // cases on Mac/Windows it defines 
diff ernt constants, referring
+    // cases on Mac/Windows it defines 
diff erent constants, referring
     // to them as "simulated" exceptions; consider moving this check
     // down to the OS-specific paths and checking each OS for its own
     // constant.

diff  --git a/lldb/source/Plugins/ScriptInterpreter/Python/PythonDataObjects.cpp b/lldb/source/Plugins/ScriptInterpreter/Python/PythonDataObjects.cpp
index 92060ee08cdc..40ed22aceebf 100644
--- a/lldb/source/Plugins/ScriptInterpreter/Python/PythonDataObjects.cpp
+++ b/lldb/source/Plugins/ScriptInterpreter/Python/PythonDataObjects.cpp
@@ -1044,7 +1044,7 @@ std::string PythonException::ReadBacktrace() const {
   if (!backtrace) {
     std::string message =
         std::string(toCString()) + "\n" +
-        "Traceback unavailble, an error occurred while reading it:\n";
+        "Traceback unavailable, an error occurred while reading it:\n";
     return (message + llvm::toString(backtrace.takeError()));
   }
 

diff  --git a/lldb/source/Plugins/ScriptInterpreter/Python/PythonDataObjects.h b/lldb/source/Plugins/ScriptInterpreter/Python/PythonDataObjects.h
index 2bab326063d9..16896803e136 100644
--- a/lldb/source/Plugins/ScriptInterpreter/Python/PythonDataObjects.h
+++ b/lldb/source/Plugins/ScriptInterpreter/Python/PythonDataObjects.h
@@ -36,7 +36,7 @@
 //   can never fail to assert instead, such as the creation of
 //   PythonString from a string literal.
 //
-// * Elimintate Reset(), and make all non-default constructors private.
+// * Eliminate Reset(), and make all non-default constructors private.
 //   Python objects should be created with Retain<> or Take<>, and they
 //   should be assigned with operator=
 //

diff  --git a/lldb/source/Plugins/StructuredData/DarwinLog/StructuredDataDarwinLog.h b/lldb/source/Plugins/StructuredData/DarwinLog/StructuredDataDarwinLog.h
index 017f8855cfd4..caa94af1f30e 100644
--- a/lldb/source/Plugins/StructuredData/DarwinLog/StructuredDataDarwinLog.h
+++ b/lldb/source/Plugins/StructuredData/DarwinLog/StructuredDataDarwinLog.h
@@ -34,7 +34,7 @@ class StructuredDataDarwinLog : public StructuredDataPlugin {
 
   /// Return whether the DarwinLog functionality is enabled.
   ///
-  /// The DarwinLog functionality is enabled if the user expicitly enabled
+  /// The DarwinLog functionality is enabled if the user explicitly enabled
   /// it with the enable command, or if the user has the setting set
   /// that controls if we always enable it for newly created/attached
   /// processes.

diff  --git a/lldb/source/Plugins/SymbolFile/PDB/SymbolFilePDB.cpp b/lldb/source/Plugins/SymbolFile/PDB/SymbolFilePDB.cpp
index eadd3b2f1642..1001514edede 100644
--- a/lldb/source/Plugins/SymbolFile/PDB/SymbolFilePDB.cpp
+++ b/lldb/source/Plugins/SymbolFile/PDB/SymbolFilePDB.cpp
@@ -1939,13 +1939,13 @@ SymbolFilePDB::GetMangledForPDBFunc(const llvm::pdb::PDBSymbolFunc &pdb_func) {
     mangled.SetMangledName(ConstString(func_decorated_name));
 
     // For MSVC, format of C funciton's decorated name depends on calling
-    // conventon. Unfortunately none of the format is recognized by current
+    // convention. Unfortunately none of the format is recognized by current
     // LLDB. For example, `_purecall` is a __cdecl C function. From PDB,
     // `__purecall` is retrieved as both its decorated and undecorated name
     // (using PDBSymbolFunc::getUndecoratedName method). However `__purecall`
     // string is not treated as mangled in LLDB (neither `?` nor `_Z` prefix).
     // Mangled::GetDemangledName method will fail internally and caches an
-    // empty string as its undecorated name. So we will face a contradition
+    // empty string as its undecorated name. So we will face a contradiction
     // here for the same symbol:
     //   non-empty undecorated name from PDB
     //   empty undecorated name from LLDB

diff  --git a/lldb/source/Plugins/TypeSystem/Clang/TypeSystemClang.cpp b/lldb/source/Plugins/TypeSystem/Clang/TypeSystemClang.cpp
index 9f425ae7c30b..ecb15201069d 100644
--- a/lldb/source/Plugins/TypeSystem/Clang/TypeSystemClang.cpp
+++ b/lldb/source/Plugins/TypeSystem/Clang/TypeSystemClang.cpp
@@ -1443,7 +1443,7 @@ TypeSystemClang::CreateTemplateTemplateParmDecl(const char *template_name) {
 
   // LLDB needs to create those decls only to be able to display a
   // type that includes a template template argument. Only the name matters for
-  // this purpose, so we use dummy values for the other characterisitcs of the
+  // this purpose, so we use dummy values for the other characteristics of the
   // type.
   return TemplateTemplateParmDecl::Create(
       ast, decl_ctx, SourceLocation(),
@@ -8419,7 +8419,7 @@ static bool DumpEnumValue(const clang::QualType &qual_type, Stream *s,
   // Try to find an exact match for the value.
   // At the same time, we're applying a heuristic to determine whether we want
   // to print this enum as a bitfield. We're likely dealing with a bitfield if
-  // every enumrator is either a one bit value or a superset of the previous
+  // every enumerator is either a one bit value or a superset of the previous
   // enumerators. Also 0 doesn't make sense when the enumerators are used as
   // flags.
   for (auto enumerator : enum_decl->enumerators()) {

diff  --git a/lldb/source/Symbol/ArmUnwindInfo.cpp b/lldb/source/Symbol/ArmUnwindInfo.cpp
index 096897b75288..f2887035e5cf 100644
--- a/lldb/source/Symbol/ArmUnwindInfo.cpp
+++ b/lldb/source/Symbol/ArmUnwindInfo.cpp
@@ -29,7 +29,7 @@
 using namespace lldb;
 using namespace lldb_private;
 
-// Converts a prel31 avlue to lldb::addr_t with sign extension
+// Converts a prel31 value to lldb::addr_t with sign extension
 static addr_t Prel31ToAddr(uint32_t prel31) {
   addr_t res = prel31;
   if (prel31 & (1 << 30))

diff  --git a/lldb/source/Target/RegisterContextUnwind.cpp b/lldb/source/Target/RegisterContextUnwind.cpp
index 2b383cba4f02..f33f4180be23 100644
--- a/lldb/source/Target/RegisterContextUnwind.cpp
+++ b/lldb/source/Target/RegisterContextUnwind.cpp
@@ -602,7 +602,7 @@ bool RegisterContextUnwind::CheckIfLoopingStack() {
   // multiple times, we compare the
   // CFA of the current
   // frame with the 2nd next frame because in some specail case (e.g. signal
-  // hanlders, hand written assembly without ABI compiance) we can have 2
+  // hanlders, hand written assembly without ABI compliance) we can have 2
   // frames with the same
   // CFA (in theory we
   // can have arbitrary number of frames with the same CFA, but more then 2 is
@@ -1094,7 +1094,7 @@ bool RegisterContextUnwind::IsValid() const {
 
 // After the final stack frame in a stack walk we'll get one invalid
 // (eNotAValidFrame) stack frame -- one past the end of the stack walk.  But
-// higher-level code will need to tell the 
diff ernece between "the unwind plan
+// higher-level code will need to tell the 
diff erence between "the unwind plan
 // below this frame failed" versus "we successfully completed the stack walk"
 // so this method helps to disambiguate that.
 

diff  --git a/lldb/source/Target/StackFrame.cpp b/lldb/source/Target/StackFrame.cpp
index 56761a6d1046..48164edcc42f 100644
--- a/lldb/source/Target/StackFrame.cpp
+++ b/lldb/source/Target/StackFrame.cpp
@@ -1499,7 +1499,7 @@ lldb::ValueObjectSP DoGuessValueAt(StackFrame &frame, ConstString reg,
   // +18 that assigns to rdi, and calls itself recursively for that dereference
   //   DoGuessValueAt(frame, rdi, 8, dis, vars, 0x18) finds the instruction at
   //   +14 that assigns to rdi, and calls itself recursively for that
-  //   derefernece
+  //   dereference
   //     DoGuessValueAt(frame, rbp, -8, dis, vars, 0x14) finds "f" in the
   //     variable list.
   //     Returns a ValueObject for f.  (That's what was stored at rbp-8 at +14)

diff  --git a/lldb/source/Target/StopInfo.cpp b/lldb/source/Target/StopInfo.cpp
index 7c920ae48e2e..7e830c6e2bed 100644
--- a/lldb/source/Target/StopInfo.cpp
+++ b/lldb/source/Target/StopInfo.cpp
@@ -453,7 +453,7 @@ class StopInfoBreakpoint : public StopInfo {
               } else {
                 LLDB_LOGF(log,
                           "Condition evaluated for breakpoint %s on thread "
-                          "0x%llx conditon_says_stop: %i.",
+                          "0x%llx condition_says_stop: %i.",
                           loc_desc.GetData(),
                           static_cast<unsigned long long>(thread_sp->GetID()),
                           condition_says_stop);

diff  --git a/lldb/test/API/benchmarks/turnaround/TestCompileRunToBreakpointTurnaround.py b/lldb/test/API/benchmarks/turnaround/TestCompileRunToBreakpointTurnaround.py
index 5bf78035be4a..88fc7455cc3a 100644
--- a/lldb/test/API/benchmarks/turnaround/TestCompileRunToBreakpointTurnaround.py
+++ b/lldb/test/API/benchmarks/turnaround/TestCompileRunToBreakpointTurnaround.py
@@ -1,4 +1,4 @@
-"""Benchmark the turnaround time starting a debugger and run to the breakpont with lldb vs. gdb."""
+"""Benchmark the turnaround time starting a debugger and run to the breakpoint with lldb vs. gdb."""
 
 from __future__ import print_function
 

diff  --git a/lldb/test/API/functionalities/breakpoint/breakpoint_names/TestBreakpointNames.py b/lldb/test/API/functionalities/breakpoint/breakpoint_names/TestBreakpointNames.py
index 74fe9473a0f3..e421140e0182 100644
--- a/lldb/test/API/functionalities/breakpoint/breakpoint_names/TestBreakpointNames.py
+++ b/lldb/test/API/functionalities/breakpoint/breakpoint_names/TestBreakpointNames.py
@@ -157,7 +157,7 @@ def do_check_using_names(self):
         # Create a dummy breakpoint to use up ID 1
         _ = self.target.BreakpointCreateByLocation(self.main_file_spec, 30)
 
-        # Create a breakpiont to test with
+        # Create a breakpoint to test with
         bkpt = self.target.BreakpointCreateByLocation(self.main_file_spec, 10)
         bkpt_name = "ABreakpoint"
         bkpt_id = bkpt.GetID()

diff  --git a/lldb/test/API/functionalities/breakpoint/step_over_breakpoint/TestStepOverBreakpoint.py b/lldb/test/API/functionalities/breakpoint/step_over_breakpoint/TestStepOverBreakpoint.py
index 4c8aa368790c..b20490f3cefd 100644
--- a/lldb/test/API/functionalities/breakpoint/step_over_breakpoint/TestStepOverBreakpoint.py
+++ b/lldb/test/API/functionalities/breakpoint/step_over_breakpoint/TestStepOverBreakpoint.py
@@ -1,7 +1,7 @@
 """
 Test that breakpoints do not affect stepping.
 Check for correct StopReason when stepping to the line with breakpoint
-which chould be eStopReasonBreakpoint in general,
+which should be eStopReasonBreakpoint in general,
 and eStopReasonPlanComplete when breakpoint's condition fails.
 """
 

diff  --git a/lldb/test/API/functionalities/load_unload/TestLoadUnload.py b/lldb/test/API/functionalities/load_unload/TestLoadUnload.py
index ae0934c74616..5c4de256fcb6 100644
--- a/lldb/test/API/functionalities/load_unload/TestLoadUnload.py
+++ b/lldb/test/API/functionalities/load_unload/TestLoadUnload.py
@@ -346,7 +346,7 @@ def run_load_unload(self):
         self.expect("breakpoint list -f", BREAKPOINT_HIT_ONCE,
                     substrs=[' resolved, hit count = 1'])
 
-        # Issue the 'contnue' command.  We should stop agaian at a_function.
+        # Issue the 'continue' command.  We should stop agaian at a_function.
         # The stop reason of the thread should be breakpoint and at a_function.
         self.runCmd("continue")
 

diff  --git a/lldb/test/API/functionalities/plugins/python_os_plugin/TestPythonOSPlugin.py b/lldb/test/API/functionalities/plugins/python_os_plugin/TestPythonOSPlugin.py
index 64c640c38e7d..ae78c24531fe 100644
--- a/lldb/test/API/functionalities/plugins/python_os_plugin/TestPythonOSPlugin.py
+++ b/lldb/test/API/functionalities/plugins/python_os_plugin/TestPythonOSPlugin.py
@@ -101,7 +101,7 @@ def run_python_os_funcionality(self):
         self.verify_os_thread_registers(thread)
 
         # Now clear the OS plug-in path to make the OS plug-in created threads
-        # dissappear
+        # disappear
         self.dbg.HandleCommand(
             "settings clear target.process.python-os-plugin-path")
 

diff  --git a/lldb/test/API/functionalities/process_crash_info/TestProcessCrashInfo.py b/lldb/test/API/functionalities/process_crash_info/TestProcessCrashInfo.py
index 6ef5018204fd..13579628ca8e 100644
--- a/lldb/test/API/functionalities/process_crash_info/TestProcessCrashInfo.py
+++ b/lldb/test/API/functionalities/process_crash_info/TestProcessCrashInfo.py
@@ -29,7 +29,7 @@ def tearDown(self):
     @skipUnlessDarwin
     def test_cli(self):
         """Test that `process status --verbose` fetches the extended crash
-        information dictionnary from the command-line properly."""
+        information dictionary from the command-line properly."""
         self.build()
         exe = self.getBuildArtifact("a.out")
         self.expect("file " + exe,
@@ -46,7 +46,7 @@ def test_cli(self):
     @skipUnlessDarwin
     def test_api(self):
         """Test that lldb can fetch a crashed process' extended crash information
-        dictionnary from the api properly."""
+        dictionary from the api properly."""
         self.build()
         target = self.dbg.CreateTarget(self.getBuildArtifact("a.out"))
         self.assertTrue(target, VALID_TARGET)
@@ -73,7 +73,7 @@ def test_api(self):
     @skipIfDarwinEmbedded
     def test_on_sane_process(self):
         """Test that lldb doesn't fetch the extended crash information
-        dictionnary from a 'sane' stopped process."""
+        dictionary from a 'sane' stopped process."""
         self.build()
         target, _, _, _ = lldbutil.run_to_line_breakpoint(self, lldb.SBFileSpec(self.source),
                                         self.line)

diff  --git a/lldb/test/API/functionalities/target-new-solib-notifications/TestModuleLoadedNotifys.py b/lldb/test/API/functionalities/target-new-solib-notifications/TestModuleLoadedNotifys.py
index b3db5f7a85da..aaaf4599ef2a 100644
--- a/lldb/test/API/functionalities/target-new-solib-notifications/TestModuleLoadedNotifys.py
+++ b/lldb/test/API/functionalities/target-new-solib-notifications/TestModuleLoadedNotifys.py
@@ -16,7 +16,7 @@ class ModuleLoadedNotifysTestCase(TestBase):
     mydir = TestBase.compute_mydir(__file__)
     NO_DEBUG_INFO_TESTCASE = True
 
-    # DyanmicLoaderDarwin should batch up notifications about
+    # DynamicLoaderDarwin should batch up notifications about
     # newly added/removed libraries.  Other DynamicLoaders may
     # not be written this way.
     @skipUnlessDarwin

diff  --git a/lldb/test/API/lang/cpp/namespace/ns3.cpp b/lldb/test/API/lang/cpp/namespace/ns3.cpp
index c6e7580b8051..c2e70040d795 100644
--- a/lldb/test/API/lang/cpp/namespace/ns3.cpp
+++ b/lldb/test/API/lang/cpp/namespace/ns3.cpp
@@ -11,7 +11,7 @@ using namespace A;
 void test_lookup_after_using_directive()
 {
   // BP_after_using_directive
-  //printf("func() = %d\n", func()); // eval func(), exp: error, amiguous
+  //printf("func() = %d\n", func()); // eval func(), exp: error, ambiguous
   std::printf("after using directive: func2() = %d\n", func2()); // eval func2(), exp: 3
   std::printf("after using directive: ::func() = %d\n", ::func()); // eval ::func(), exp: 1
   std::printf("after using directive: B::func() = %d\n", B::func()); // eval B::func(), exp: 4

diff  --git a/lldb/test/API/macosx/lc-note/kern-ver-str/TestKernVerStrLCNOTE.py b/lldb/test/API/macosx/lc-note/kern-ver-str/TestKernVerStrLCNOTE.py
index 167f0984fc6c..98f3e67ed0f6 100644
--- a/lldb/test/API/macosx/lc-note/kern-ver-str/TestKernVerStrLCNOTE.py
+++ b/lldb/test/API/macosx/lc-note/kern-ver-str/TestKernVerStrLCNOTE.py
@@ -51,7 +51,7 @@ def test_lc_note(self):
                 'echo "<!DOCTYPE plist PUBLIC \\"-//Apple//DTD PLIST 1.0//EN\\" \\"http://www.apple.com/DTDs/PropertyList-1.0.dtd\\">"',
                 'echo "<plist version=\\"1.0\\">"',
                 '',
-                '# the last arugment is probably the uuid',
+                '# the last argument is probably the uuid',
                 'while [ $# -gt 1 ]',
                 'do',
                 '  shift',

diff  --git a/lldb/test/API/macosx/lc-note/kern-ver-str/create-empty-corefile.cpp b/lldb/test/API/macosx/lc-note/kern-ver-str/create-empty-corefile.cpp
index 8a8115af9672..3123542c2ac5 100644
--- a/lldb/test/API/macosx/lc-note/kern-ver-str/create-empty-corefile.cpp
+++ b/lldb/test/API/macosx/lc-note/kern-ver-str/create-empty-corefile.cpp
@@ -274,7 +274,7 @@ int main (int argc, char **argv)
 
     int header_and_load_cmd_room = sizeof (struct mach_header_64) + size_of_load_commands;
 
-    // Erease the load commands / payload now that we know how much space is needed,
+    // Erase the load commands / payload now that we know how much space is needed,
     // redo it.
     load_commands.clear();
     payload.clear();

diff  --git a/lldb/test/API/python_api/default-constructor/TestDefaultConstructorForAPIObjects.py b/lldb/test/API/python_api/default-constructor/TestDefaultConstructorForAPIObjects.py
index e00206587edd..09f44f554118 100644
--- a/lldb/test/API/python_api/default-constructor/TestDefaultConstructorForAPIObjects.py
+++ b/lldb/test/API/python_api/default-constructor/TestDefaultConstructorForAPIObjects.py
@@ -7,7 +7,7 @@
 C++ API counterpart.  Passing None should not crash lldb!
 
 There are three exceptions to the above general rules, though; API objects
-SBCommadnReturnObject, SBStream, and SBSymbolContextList, are all valid objects
+SBCommandReturnObject, SBStream, and SBSymbolContextList, are all valid objects
 after default construction.
 """
 

diff  --git a/lldb/test/API/python_api/frame/TestFrames.py b/lldb/test/API/python_api/frame/TestFrames.py
index 91ac30e36e36..6d4b7b51f426 100644
--- a/lldb/test/API/python_api/frame/TestFrames.py
+++ b/lldb/test/API/python_api/frame/TestFrames.py
@@ -114,7 +114,7 @@ def test_get_arg_vals_for_call_stack(self):
         if self.TraceOn():
             print("Full stack traces when stopped on the breakpoint 'c':")
             print(session.getvalue())
-        self.expect(session.getvalue(), "Argugment values displayed correctly",
+        self.expect(session.getvalue(), "Argument values displayed correctly",
                     exe=False,
                     substrs=["a((int)val=1, (char)ch='A')",
                              "a((int)val=3, (char)ch='A')"])

diff  --git a/lldb/test/API/python_api/function_symbol/main.c b/lldb/test/API/python_api/function_symbol/main.c
index 7dc18d231ddf..d5f8cebc5a00 100644
--- a/lldb/test/API/python_api/function_symbol/main.c
+++ b/lldb/test/API/python_api/function_symbol/main.c
@@ -3,7 +3,7 @@
 // This simple program is to test the lldb Python APIs SBTarget, SBFrame,
 // SBFunction, SBSymbol, and SBAddress.
 //
-// When stopped on breakppint 1, we can get the line entry using SBFrame API
+// When stopped on breakpoint 1, we can get the line entry using SBFrame API
 // SBFrame.GetLineEntry().  We'll get the start address for the line entry
 // with the SBAddress type, resolve the symbol context using the SBTarget API
 // SBTarget.ResolveSymbolContextForAddress() in order to get the SBSymbol.

diff  --git a/lldb/test/API/python_api/target/main.c b/lldb/test/API/python_api/target/main.c
index 0d0580dd10e9..7724fa74d9ef 100644
--- a/lldb/test/API/python_api/target/main.c
+++ b/lldb/test/API/python_api/target/main.c
@@ -2,7 +2,7 @@
 
 // This simple program is to test the lldb Python API SBTarget.
 //
-// When stopped on breakppint 1, and then 2, we can get the line entries using
+// When stopped on breakpoint 1, and then 2, we can get the line entries using
 // SBFrame API SBFrame.GetLineEntry().  We'll get the start addresses for the
 // two line entries; with the start address (of SBAddress type), we can then
 // resolve the symbol context using the SBTarget API

diff  --git a/lldb/test/API/python_api/thread/TestThreadAPI.py b/lldb/test/API/python_api/thread/TestThreadAPI.py
index 912413852932..87d4eb8ae712 100644
--- a/lldb/test/API/python_api/thread/TestThreadAPI.py
+++ b/lldb/test/API/python_api/thread/TestThreadAPI.py
@@ -72,7 +72,7 @@ def setUp(self):
             "main2.cpp", "// we should reach here after 3 step-over's.")
 
         # We'll use the test method name as the exe_name for executable
-        # comppiled from main2.cpp.
+        # compiled from main2.cpp.
         self.exe_name = self.testMethodName
 
     def get_process(self):

diff  --git a/lldb/test/API/tools/lldb-server/main.cpp b/lldb/test/API/tools/lldb-server/main.cpp
index 399b5e9033b4..4a877deaafbd 100644
--- a/lldb/test/API/tools/lldb-server/main.cpp
+++ b/lldb/test/API/tools/lldb-server/main.cpp
@@ -337,7 +337,7 @@ int main(int argc, char **argv) {
     } else if (std::strstr(argv[i], CALL_FUNCTION_PREFIX)) {
       void (*func_p)() = nullptr;
 
-      // Defaut to providing the address of main.
+      // Default to providing the address of main.
       if (std::strcmp(argv[i] + strlen(CALL_FUNCTION_PREFIX), "hello") == 0)
         func_p = hello;
       else if (std::strcmp(argv[i] + strlen(CALL_FUNCTION_PREFIX),

diff  --git a/lldb/test/API/tools/lldb-vscode/attach/TestVSCode_attach.py b/lldb/test/API/tools/lldb-vscode/attach/TestVSCode_attach.py
index 9d9553fcdf68..bd66f98270ce 100644
--- a/lldb/test/API/tools/lldb-vscode/attach/TestVSCode_attach.py
+++ b/lldb/test/API/tools/lldb-vscode/attach/TestVSCode_attach.py
@@ -35,7 +35,7 @@ def set_and_hit_breakpoint(self, continueToExit=True):
         source = 'main.c'
         breakpoint1_line = line_number(source, '// breakpoint 1')
         lines = [breakpoint1_line]
-        # Set breakoint in the thread function so we can step the threads
+        # Set breakpoint in the thread function so we can step the threads
         breakpoint_ids = self.set_source_breakpoints(source, lines)
         self.assertEqual(len(breakpoint_ids), len(lines),
                          "expect correct number of breakpoints")

diff  --git a/lldb/test/API/tools/lldb-vscode/breakpoint/TestVSCode_setBreakpoints.py b/lldb/test/API/tools/lldb-vscode/breakpoint/TestVSCode_setBreakpoints.py
index dde9989703fb..b0f7a459d41a 100644
--- a/lldb/test/API/tools/lldb-vscode/breakpoint/TestVSCode_setBreakpoints.py
+++ b/lldb/test/API/tools/lldb-vscode/breakpoint/TestVSCode_setBreakpoints.py
@@ -24,7 +24,7 @@ def test_set_and_clear(self):
            is no "clearBreakpoints" packet. Source file and line breakpoints
            are set by sending a "setBreakpoints" packet with a source file
            specified and zero or more source lines. If breakpoints have been
-           set in the source file before, any exising breakpoints must remain
+           set in the source file before, any existing breakpoints must remain
            set, and any new breakpoints must be created, and any breakpoints
            that were in previous requests and are not in the current request
            must be removed. This function tests this setting and clearing
@@ -44,7 +44,7 @@ def test_set_and_clear(self):
         program = self.getBuildArtifact("a.out")
         self.build_and_launch(program)
 
-        # Set 3 breakoints and verify that they got set correctly
+        # Set 3 breakpoints and verify that they got set correctly
         response = self.vscode.request_setBreakpoints(source_path, lines)
         line_to_id = {}
         if response:
@@ -68,7 +68,7 @@ def test_set_and_clear(self):
         # breakpoint and set it again at the same location. We also need to
         # verify that the second line location was actually removed.
         lines.remove(second_line)
-        # Set 2 breakoints and verify that the previous breakoints that were
+        # Set 2 breakpoints and verify that the previous breakpoints that were
         # set above are still set.
         response = self.vscode.request_setBreakpoints(source_path, lines)
         if response:
@@ -195,7 +195,7 @@ def test_functionality(self):
                         "existing breakpoint should have its condition "
                         "updated")
 
-        # Continue with a hitContidtion of 2 and expect it to skip 1 value
+        # Continue with a hitCondition of 2 and expect it to skip 1 value
         self.continue_to_breakpoints(breakpoint_ids)
         i = int(self.vscode.get_local_variable_value('i'))
         self.assertEquals(i, 6,

diff  --git a/lldb/test/API/tools/lldb-vscode/breakpoint/TestVSCode_setExceptionBreakpoints.py b/lldb/test/API/tools/lldb-vscode/breakpoint/TestVSCode_setExceptionBreakpoints.py
index 36c0cfe82dc3..d5ec9d39d587 100644
--- a/lldb/test/API/tools/lldb-vscode/breakpoint/TestVSCode_setExceptionBreakpoints.py
+++ b/lldb/test/API/tools/lldb-vscode/breakpoint/TestVSCode_setExceptionBreakpoints.py
@@ -25,7 +25,7 @@ def test_functionality(self):
            is no "clear exception breakpoints" packet. Exception breakpoints
            are set by sending a "setExceptionBreakpoints" packet with zero or
            more exception filters. If exception breakpoints have been set
-           before, any exising breakpoints must remain set, and any new
+           before, any existing breakpoints must remain set, and any new
            breakpoints must be created, and any breakpoints that were in
            previous requests and are not in the current request must be
            removed. This exception tests this setting and clearing and makes

diff  --git a/lldb/test/API/tools/lldb-vscode/breakpoint/TestVSCode_setFunctionBreakpoints.py b/lldb/test/API/tools/lldb-vscode/breakpoint/TestVSCode_setFunctionBreakpoints.py
index 306c1ce8077a..651a7071a5a7 100644
--- a/lldb/test/API/tools/lldb-vscode/breakpoint/TestVSCode_setFunctionBreakpoints.py
+++ b/lldb/test/API/tools/lldb-vscode/breakpoint/TestVSCode_setFunctionBreakpoints.py
@@ -24,7 +24,7 @@ def test_set_and_clear(self):
            is no "clearFunction Breakpoints" packet. Function breakpoints
            are set by sending a "setFunctionBreakpoints" packet with zero or
            more function names. If function breakpoints have been set before,
-           any exising breakpoints must remain set, and any new breakpoints
+           any existing breakpoints must remain set, and any new breakpoints
            must be created, and any breakpoints that were in previous requests
            and are not in the current request must be removed. This function
            tests this setting and clearing and makes sure things happen
@@ -147,7 +147,7 @@ def test_functionality(self):
                         "existing breakpoint should have its condition "
                         "updated")
 
-        # Continue with a hitContidtion of 2 and expect it to skip 1 value
+        # Continue with a hitCondition of 2 and expect it to skip 1 value
         self.continue_to_breakpoints(breakpoint_ids)
         i = int(self.vscode.get_local_variable_value('i'))
         self.assertEquals(i, 6,

diff  --git a/lldb/test/API/tools/lldb-vscode/launch/TestVSCode_launch.py b/lldb/test/API/tools/lldb-vscode/launch/TestVSCode_launch.py
index 0d20dd0987ac..f7f314d76f25 100644
--- a/lldb/test/API/tools/lldb-vscode/launch/TestVSCode_launch.py
+++ b/lldb/test/API/tools/lldb-vscode/launch/TestVSCode_launch.py
@@ -330,7 +330,7 @@ def test_commands(self):
         second_line = line_number(source, '// breakpoint 2')
         lines = [first_line, second_line]
 
-        # Set 2 breakoints so we can verify that "stopCommands" get run as the
+        # Set 2 breakpoints so we can verify that "stopCommands" get run as the
         # breakpoints get hit
         breakpoint_ids = self.set_source_breakpoints(source, lines)
         self.assertEquals(len(breakpoint_ids), len(lines),
@@ -369,7 +369,7 @@ def test_extra_launch_commands(self):
         source = 'main.c'
         first_line = line_number(source, '// breakpoint 1')
         second_line = line_number(source, '// breakpoint 2')
-        # Set target binary and 2 breakoints
+        # Set target binary and 2 breakpoints
         # then we can varify the "launchCommands" get run
         # also we can verify that "stopCommands" get run as the
         # breakpoints get hit

diff  --git a/lldb/test/API/tools/lldb-vscode/stackTrace/TestVSCode_stackTrace.py b/lldb/test/API/tools/lldb-vscode/stackTrace/TestVSCode_stackTrace.py
index 9c01577f52b8..153fb9af0bb5 100644
--- a/lldb/test/API/tools/lldb-vscode/stackTrace/TestVSCode_stackTrace.py
+++ b/lldb/test/API/tools/lldb-vscode/stackTrace/TestVSCode_stackTrace.py
@@ -67,7 +67,7 @@ def test_stackTrace(self):
 
         lines = [self.recurse_end]
 
-        # Set breakoint at a point of deepest recuusion
+        # Set breakpoint at a point of deepest recuusion
         breakpoint_ids = self.set_source_breakpoints(source, lines)
         self.assertEquals(len(breakpoint_ids), len(lines),
                         "expect correct number of breakpoints")

diff  --git a/lldb/test/API/tools/lldb-vscode/step/TestVSCode_step.py b/lldb/test/API/tools/lldb-vscode/step/TestVSCode_step.py
index dbe3cde744f7..dbd7ef8499d8 100644
--- a/lldb/test/API/tools/lldb-vscode/step/TestVSCode_step.py
+++ b/lldb/test/API/tools/lldb-vscode/step/TestVSCode_step.py
@@ -27,7 +27,7 @@ def test_step(self):
         # source_path = os.path.join(os.getcwd(), source)
         breakpoint1_line = line_number(source, '// breakpoint 1')
         lines = [breakpoint1_line]
-        # Set breakoint in the thread function so we can step the threads
+        # Set breakpoint in the thread function so we can step the threads
         breakpoint_ids = self.set_source_breakpoints(source, lines)
         self.assertEqual(len(breakpoint_ids), len(lines),
                         "expect correct number of breakpoints")

diff  --git a/lldb/test/Shell/SymbolFile/DWARF/anon_class_w_and_wo_export_symbols.ll b/lldb/test/Shell/SymbolFile/DWARF/anon_class_w_and_wo_export_symbols.ll
index 40a8ac037c2a..c61012b60535 100644
--- a/lldb/test/Shell/SymbolFile/DWARF/anon_class_w_and_wo_export_symbols.ll
+++ b/lldb/test/Shell/SymbolFile/DWARF/anon_class_w_and_wo_export_symbols.ll
@@ -1,7 +1,7 @@
 ; UNSUPPORTED: system-windows
 ;
 ; This test verifies that we do the right thing with DIFlagExportSymbols which is the new
-; behavioir and without the DIFlagExportSymbols which is the old behavior for the given
+; behaviour and without the DIFlagExportSymbols which is the old behavior for the given
 ; definitions below.
 ;
 ;```

diff  --git a/lldb/third_party/Python/module/pexpect-4.6/pexpect/spawnbase.py b/lldb/third_party/Python/module/pexpect-4.6/pexpect/spawnbase.py
index 63c0b4204eb9..4bebe1158478 100644
--- a/lldb/third_party/Python/module/pexpect-4.6/pexpect/spawnbase.py
+++ b/lldb/third_party/Python/module/pexpect-4.6/pexpect/spawnbase.py
@@ -150,7 +150,7 @@ def _set_buffer(self, value):
         self._buffer = self.buffer_type()
         self._buffer.write(value)
 
-    # This property is provided for backwards compatability (self.buffer used
+    # This property is provided for backwards compatibility (self.buffer used
     # to be a string/bytes object)
     buffer = property(_get_buffer, _set_buffer)
 

diff  --git a/lldb/tools/debugserver/source/ChangeLog b/lldb/tools/debugserver/source/ChangeLog
index 898f2fba7b04..06da01849e21 100644
--- a/lldb/tools/debugserver/source/ChangeLog
+++ b/lldb/tools/debugserver/source/ChangeLog
@@ -113,7 +113,7 @@
 	(RNBRemote::HandleReceivedPacket): Ditto.
 	(RNBRemote::CommDataReceived): Ditto.
 	* DNB.cpp (DNBProcessLaunch): Changed to take a eror string pointer with 
-	size for more desciptive error reporting (instead of a uint32_t pointer).
+	size for more descriptive error reporting (instead of a uint32_t pointer).
 	* DNB.h (DNBProcessLaunch): Ditto.
 	* DNBError.cpp (DNBError::AsString): Now returns NULL if there is no error.
 	* DNBError.h (DNBError::SetErrorString): New accessor to allow custom error
@@ -268,10 +268,10 @@
 	qualifier to allow arches to auto detect how many hardware watchpoints they 
 	have.
 	* DNBArchImpl.h (DNBArchMachARM::NumSupportedHardwareBreakpoints()): Auto
-	detect how many BRP pairs are avialable and disable for armv7 for the time
+	detect how many BRP pairs are available and disable for armv7 for the time
 	being (rdar://problem/6372672).
 	(DNBArchMachARM::NumSupportedHardwareWatchpoints()): Auto detect how many 
-	WRP pairs are avialable and disable for armv7 for the time being 
+	WRP pairs are available and disable for armv7 for the time being
 	(rdar://problem/6372672).
 
 2009-01-09  Greg Clayton  <gclayton at apple.com>
@@ -692,7 +692,7 @@
 2008-10-17  Greg Clayton  <gclayton at apple.com>
 
 	* test-remotenub.cpp (RNBRunLoopLaunchInferior): Don't listen for
-	the qLaunchSuccess if we aren't doing a lockdown connnection.
+	the qLaunchSuccess if we aren't doing a lockdown connection.
 
 2008-10-13  Greg Clayton  <gclayton at apple.com>
 

diff  --git a/lldb/tools/debugserver/source/MacOSX/CFUtils.h b/lldb/tools/debugserver/source/MacOSX/CFUtils.h
index fcd1eb41172b..ef2958314330 100644
--- a/lldb/tools/debugserver/source/MacOSX/CFUtils.h
+++ b/lldb/tools/debugserver/source/MacOSX/CFUtils.h
@@ -22,7 +22,7 @@
 // explicitly released using the release() member function.
 template <class T> class CFReleaser {
 public:
-  // Type names for the avlue
+  // Type names for the value
   typedef T element_type;
 
   // Constructors and destructors

diff  --git a/lldb/tools/debugserver/source/MacOSX/MachProcess.h b/lldb/tools/debugserver/source/MacOSX/MachProcess.h
index ec3a852ad839..e62051fbe011 100644
--- a/lldb/tools/debugserver/source/MacOSX/MachProcess.h
+++ b/lldb/tools/debugserver/source/MacOSX/MachProcess.h
@@ -421,7 +421,7 @@ class MachProcess {
   // we don't report a spurious stop on the next resume.
   int m_auto_resume_signo; // If we resume the process and still haven't
                            // received our interrupt signal
-  // acknownledgement, we will shortly after the next resume. We store the
+  // acknowledgement, we will shortly after the next resume. We store the
   // interrupt signal in this variable so when we get the interrupt signal
   // as the sole reason for the process being stopped, we can auto resume
   // the process.

diff  --git a/lldb/tools/lldb-test/lldb-test.cpp b/lldb/tools/lldb-test/lldb-test.cpp
index ef6053297328..5b28afbf8972 100644
--- a/lldb/tools/lldb-test/lldb-test.cpp
+++ b/lldb/tools/lldb-test/lldb-test.cpp
@@ -132,7 +132,7 @@ static cl::opt<std::string> Name("name", cl::desc("Name to find."),
                                  cl::sub(SymbolsSubcommand));
 static cl::opt<bool>
     Regex("regex",
-          cl::desc("Search using regular expressions (avaliable for variables "
+          cl::desc("Search using regular expressions (available for variables "
                    "and functions only)."),
           cl::sub(SymbolsSubcommand));
 static cl::opt<std::string>
@@ -651,7 +651,7 @@ Error opts::symbols::verify(lldb_private::Module &Module) {
   for (uint32_t i = 0; i < comp_units_count; i++) {
     lldb::CompUnitSP comp_unit = symfile->GetCompileUnitAtIndex(i);
     if (!comp_unit)
-      return make_string_error("Connot parse compile unit {0}.", i);
+      return make_string_error("Cannot parse compile unit {0}.", i);
 
     outs() << "Processing '"
            << comp_unit->GetPrimaryFile().GetFilename().AsCString()

diff  --git a/lldb/tools/lldb-vscode/JSONUtils.h b/lldb/tools/lldb-vscode/JSONUtils.h
index 6dc670104a15..e1911ef91187 100644
--- a/lldb/tools/lldb-vscode/JSONUtils.h
+++ b/lldb/tools/lldb-vscode/JSONUtils.h
@@ -221,7 +221,7 @@ llvm::json::Object CreateEventObject(const llvm::StringRef event_name);
 /// the Visual Studio Code debug adaptor definition.
 ///
 /// \param[in] bp
-///     The exception breakppoint object to use
+///     The exception breakpoint object to use
 ///
 /// \return
 ///     A "ExceptionBreakpointsFilter" JSON object with that follows

diff  --git a/lldb/tools/lldb-vscode/package.json b/lldb/tools/lldb-vscode/package.json
index 2058edf68550..8dabf3de1ec2 100644
--- a/lldb/tools/lldb-vscode/package.json
+++ b/lldb/tools/lldb-vscode/package.json
@@ -115,7 +115,7 @@
 							},
 							"sourceMap": {
 								"type": "array",
-								"description": "Specify an array of path remappings; each element must itself be a two element array containing a source and desination pathname. Overrides sourcePath.",
+								"description": "Specify an array of path remappings; each element must itself be a two element array containing a source and destination pathname. Overrides sourcePath.",
 								"default": []
 							},
 							"debuggerRoot": {
@@ -181,7 +181,7 @@
 							},
 							"sourceMap": {
 								"type": "array",
-								"description": "Specify an array of path remappings; each element must itself be a two element array containing a source and desination pathname. Overrides sourcePath.",
+								"description": "Specify an array of path remappings; each element must itself be a two element array containing a source and destination pathname. Overrides sourcePath.",
 								"default": []
 							},
 							"debuggerRoot": {

diff  --git a/lldb/unittests/Process/Linux/ProcessorTraceTest.cpp b/lldb/unittests/Process/Linux/ProcessorTraceTest.cpp
index 7f141cb48db4..3615135cccb4 100644
--- a/lldb/unittests/Process/Linux/ProcessorTraceTest.cpp
+++ b/lldb/unittests/Process/Linux/ProcessorTraceTest.cpp
@@ -31,7 +31,7 @@ TEST(CyclicBuffer, EdgeCases) {
   uint8_t cyclic_buffer[6] = {'l', 'i', 'c', 'c', 'y', 'c'};
 
   // We will always leave the last bytes untouched
-  // so that string comparisions work.
+  // so that string comparisons work.
   char smaller_buffer[4] = {};
 
   // empty buffer to read into
@@ -70,7 +70,7 @@ TEST(CyclicBuffer, EqualSizeBuffer) {
   char cyclic[] = "cyclic";
   for (size_t i = 0; i < sizeof(cyclic); i++) {
     // We will always leave the last bytes untouched
-    // so that string comparisions work.
+    // so that string comparisons work.
     char equal_size_buffer[7] = {};
     bytes_read =
         ReadCylicBufferWrapper(equal_size_buffer, sizeof(cyclic_buffer),
@@ -85,7 +85,7 @@ TEST(CyclicBuffer, SmallerSizeBuffer) {
   uint8_t cyclic_buffer[6] = {'l', 'i', 'c', 'c', 'y', 'c'};
 
   // We will always leave the last bytes untouched
-  // so that string comparisions work.
+  // so that string comparisons work.
   char smaller_buffer[4] = {};
   bytes_read =
       ReadCylicBufferWrapper(smaller_buffer, (sizeof(smaller_buffer) - 1),
@@ -136,7 +136,7 @@ TEST(CyclicBuffer, BiggerSizeBuffer) {
   char cyclic[] = "cyclic";
   for (size_t i = 0; i < sizeof(cyclic); i++) {
     // We will always leave the last bytes untouched
-    // so that string comparisions work.
+    // so that string comparisons work.
     char bigger_buffer[10] = {};
     bytes_read =
         ReadCylicBufferWrapper(bigger_buffer, (sizeof(bigger_buffer) - 1),

diff  --git a/lldb/unittests/Utility/ArchSpecTest.cpp b/lldb/unittests/Utility/ArchSpecTest.cpp
index a5ad68b6bbad..4e8e2f3c34d7 100644
--- a/lldb/unittests/Utility/ArchSpecTest.cpp
+++ b/lldb/unittests/Utility/ArchSpecTest.cpp
@@ -281,7 +281,7 @@ TEST(ArchSpecTest, Compatibility) {
     ASSERT_TRUE(A.IsCompatibleMatch(B));
   }
   {
-    // The version information is auxiliary to support availablity but
+    // The version information is auxiliary to support availability but
     // doesn't affect compatibility.
     ArchSpec A("x86_64-apple-macosx10.11");
     ArchSpec B("x86_64-apple-macosx10.12");

diff  --git a/lldb/unittests/debugserver/CMakeLists.txt b/lldb/unittests/debugserver/CMakeLists.txt
index a72b805c65b1..66c4c639fc89 100644
--- a/lldb/unittests/debugserver/CMakeLists.txt
+++ b/lldb/unittests/debugserver/CMakeLists.txt
@@ -1,6 +1,6 @@
 # Note: debugserver is a Darwin-only implementation of a remote debugging
 # server. It is not intended to be used on other platforms. The tests are here
-# because using the LLDB Host API is convienent and allows testing of both parts
+# because using the LLDB Host API is convenient and allows testing of both parts
 # of the debugserver communication path. If you are looking for a non-darwin
 # remote debugging server, please use lldb-server.
 


        


More information about the lldb-commits mailing list
diff  --git a/lldb/test/API/tools/lldb-vscode/breakpoint-events/TestVSCode_breakpointEvents.py b/lldb/test/API/tools/lldb-vscode/breakpoint-events/TestVSCode_breakpointEvents.py
index e9d826073f21..3a221cd0478c 100644
--- a/lldb/test/API/tools/lldb-vscode/breakpoint-events/TestVSCode_breakpointEvents.py
+++ b/lldb/test/API/tools/lldb-vscode/breakpoint-events/TestVSCode_breakpointEvents.py
@@ -28,7 +28,7 @@ def test_breakpoint_events(self):
             breakpoint event that informs us that the breakpoint in the shared
             library is "changed" and the correct line number should be
             supplied. We also set a breakpoint using a LLDB command using the
-            "preRunCommands" when launching our program. Any breapoints set via
+            "preRunCommands" when launching our program. Any breakpoints set via
             the command interpreter should not be have breakpoint events sent
             back to VS Code as the UI isn't able to add new breakpoints to
             their UI. Code has been added that tags breakpoints set from VS Code
@@ -62,7 +62,7 @@ def test_breakpoint_events(self):
                               preRunCommands=[bp_command])
         main_bp_id = 0
         foo_bp_id = 0
         # Set breakoints and verify that they got set correctly
         vscode_breakpoint_ids = []
         response = self.vscode.request_setBreakpoints(main_source_path,
                                                       [main_bp_line])
@@ -62,7 +62,7 @@ def test_breakpoint_events(self):
         main_bp_id = 0
         foo_bp_id = 0
-        # Set breakoints and verify that they got set correctly
+        # Set breakpoints and verify that they got set correctly
         vscode_breakpoint_ids = []
         response = self.vscode.request_setBreakpoints(main_source_path,
